summaryrefslogtreecommitdiffstats
path: root/generic/tkImgPhoto.h
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-03 07:14:25 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-03 07:14:25 (GMT)
commit01d0823e8cde70b183341a77526428c573b8fd09 (patch)
tree9ffca2470cd6b5d33905d261c7fa281b0dd7a945 /generic/tkImgPhoto.h
parentb19d4dada534a8bd99260351c5e6d8252f80019d (diff)
parent18cb58ab84107c6049642f8aea423dd75e25e4c1 (diff)
downloadtk-01d0823e8cde70b183341a77526428c573b8fd09.zip
tk-01d0823e8cde70b183341a77526428c573b8fd09.tar.gz
tk-01d0823e8cde70b183341a77526428c573b8fd09.tar.bz2
Merge 8.6
Diffstat (limited to 'generic/tkImgPhoto.h')
-rw-r--r--generic/tkImgPhoto.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/generic/tkImgPhoto.h b/generic/tkImgPhoto.h
index a84ebb3..c6e32e3 100644
--- a/generic/tkImgPhoto.h
+++ b/generic/tkImgPhoto.h
@@ -27,10 +27,11 @@
* Forward declarations of the structures we define.
*/
+#define PhotoMaster PhotoModel
typedef struct ColorTableId ColorTableId;
typedef struct ColorTable ColorTable;
typedef struct PhotoInstance PhotoInstance;
-typedef struct PhotoMaster PhotoMaster;
+typedef struct PhotoModel PhotoModel;
/*
* A signed 8-bit integral type. If chars are unsigned and the compiler isn't
@@ -147,8 +148,8 @@ struct ColorTable {
* Definition of the data associated with each photo image master.
*/
-struct PhotoMaster {
- Tk_ImageMaster tkMaster; /* Tk's token for image master. NULL means the
+struct PhotoModel {
+ Tk_ImageModel tkMaster; /* Tk's token for image model. NULL means the
* image is being deleted. */
Tcl_Interp *interp; /* Interpreter associated with the application
* using this image. */
@@ -175,7 +176,7 @@ struct PhotoMaster {
};
/*
* Bit definitions for the flags field of a PhotoMaster.
* COLOR_IMAGE: 1 means that the image has different color
* components.
* IMAGE_CHANGED: 1 means that the instances of this image need
@@ -202,7 +203,7 @@ struct PhotoMaster {
*/
struct PhotoInstance {
- PhotoMaster *masterPtr; /* Pointer to master for image. */
+ PhotoModel *modelPtr; /* Pointer to model for image. */
Display *display; /* Display for windows using this instance. */
Colormap colormap; /* The image may only be used in windows with
* this particular colormap. */
@@ -175,7 +176,7 @@ struct PhotoMaster {
};
/*
- * Bit definitions for the flags field of a PhotoMaster.
+ * Bit definitions for the flags field of a PhotoModel.
* COLOR_IMAGE: 1 means that the image has different color
* components.